"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const querystring_1 = __importDefault(require("querystring"));
const helper_1 = require("./utils/helper");
const BASE_URL = "https://api.hubtel.com/v1/messages";
class HubtelSms {
    constructor(config) {
        this.config = config;
        if (!(config.clientId && config.clientSecret)) {
            throw new Error("Invalid Configuration");
        }
        this.headers = Object.assign({}, helper_1.getCommonHeaders(this.config.clientId, this.config.clientSecret));
    }
    /**
     * @async
     * @param {QuickSendMessage} QuickSendMessage
     * @returns {Promise<SendMessageResponse>} Promise<SendMessageResponse>
     */
    quickSend(data) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield axios_1.default.get(`${BASE_URL}/send?${querystring_1.default.stringify(Object.assign({}, data))}&ClientId=${this.config.clientId}&ClientSecret=${this.config.clientSecret}`);
                return response.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    ;
    /**
     * @async
     * @param {SendMessage} SendMessage
     * @returns {Promise<SendMessageResponse>} Promise<SendMessageResponse>
     */
    sendMessage(data) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield axios_1.default.post(`${BASE_URL}`, data, {
                    headers: this.headers
                });
                return response.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    ;
    /**
     * @async
     * @param {string} MessageId
     * @returns {Promise<Message>} Promise<Message>
     */
    getMessage(MessageId) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield axios_1.default.get(`${BASE_URL}/${MessageId}`, {
                    headers: this.headers
                });
                return response.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    ;
    /**
     * @async
     * @returns {Promise<QueryMessageResponse>} Promise<QueryMessageResponse>
     */
    queryMessage() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield axios_1.default.get(`${BASE_URL}`, {
                    headers: this.headers
                });
                return response.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    ;
    /**
     * @async
     * @param {ScheduleMessage} ScheduleMessage
     * @returns {Promise<SendMessageResponse>} Promise<SendMessageResponse>
     */
    scheduleMessage(data) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield axios_1.default.post(`${BASE_URL}`, data, {
                    headers: this.headers
                });
                return response.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    ;
    /**
     * @async
     * @param {string} MessageId
     * @param {string} Time
     * @returns {Promise<SendMessageResponse>} Promise<SendMessageResponse>
     */
    //Not Working
    rescheduleScheduledMessage(MessageId, Time) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield axios_1.default.put(`${BASE_URL}/${MessageId}`, { Time }, {
                    headers: this.headers
                });
                return response.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    ;
    /**
     * @async
     * @param {string} MessageId
     * @returns {Promise<CancelScheduledMessageResponse>} Promise<CancelScheduledMessageResponse>
     */
    cancelScheduledMessage(MessageId) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield axios_1.default.delete(`${BASE_URL}/${MessageId}`, {
                    headers: this.headers
                });
                return response.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    ;
}
exports.HubtelSms = HubtelSms;
